|     | id                                                                   | dataset_name                              | config_name                                   | task_name      | preprocessing_name                           | task_type           |
|----:|:---------------------------------------------------------------------|:------------------------------------------|:----------------------------------------------|:---------------|:---------------------------------------------|:--------------------|
|   0 | glue/mnli                                                            | glue                                      | mnli                                          |                | glue___mnli                                  | Classification      |
|   1 | glue/qnli                                                            | glue                                      | qnli                                          |                | glue___qnli                                  | Classification      |
|   2 | glue/rte                                                             | glue                                      | rte                                           |                | glue___rte                                   | Classification      |
|   3 | glue/wnli                                                            | glue                                      | wnli                                          |                | glue___wnli                                  | Classification      |
|   4 | glue/mrpc                                                            | glue                                      | mrpc                                          |                | glue___mrpc                                  | Classification      |
|   5 | glue/qqp                                                             | glue                                      | qqp                                           |                | glue___qqp                                   | Classification      |
|   6 | glue/stsb                                                            | glue                                      | stsb                                          |                | glue___stsb                                  | Classification      |
|   7 | super_glue/boolq                                                     | super_glue                                | boolq                                         |                | super_glue___boolq                           | Classification      |
|   8 | super_glue/cb                                                        | super_glue                                | cb                                            |                | super_glue___cb                              | Classification      |
|   9 | super_glue/multirc                                                   | super_glue                                | multirc                                       |                | super_glue___multirc                         | Classification      |
|  10 | super_glue/wic                                                       | super_glue                                | wic                                           |                | super_glue___wic                             | Classification      |
|  11 | super_glue/axg                                                       | super_glue                                | axg                                           |                | super_glue___axg                             | Classification      |
|  12 | anli/a1                                                              | anli                                      |                                               | a1             | anli__a1                                     | Classification      |
|  13 | anli/a2                                                              | anli                                      |                                               | a2             | anli__a2                                     | Classification      |
|  14 | anli/a3                                                              | anli                                      |                                               | a3             | anli__a3                                     | Classification      |
|  15 | babi_nli/compound-coreference                                        | metaeval/babi_nli                         | compound-coreference                          |                | babi_nli                                     | Classification      |
|  16 | babi_nli/conjunction                                                 | metaeval/babi_nli                         | conjunction                                   |                | babi_nli                                     | Classification      |
|  17 | babi_nli/basic-deduction                                             | metaeval/babi_nli                         | basic-deduction                               |                | babi_nli                                     | Classification      |
|  18 | babi_nli/counting                                                    | metaeval/babi_nli                         | counting                                      |                | babi_nli                                     | Classification      |
|  19 | babi_nli/simple-negation                                             | metaeval/babi_nli                         | simple-negation                               |                | babi_nli                                     | Classification      |
|  20 | babi_nli/indefinite-knowledge                                        | metaeval/babi_nli                         | indefinite-knowledge                          |                | babi_nli                                     | Classification      |
|  21 | babi_nli/positional-reasoning                                        | metaeval/babi_nli                         | positional-reasoning                          |                | babi_nli                                     | Classification      |
|  22 | babi_nli/two-supporting-facts                                        | metaeval/babi_nli                         | two-supporting-facts                          |                | babi_nli                                     | Classification      |
|  23 | babi_nli/basic-coreference                                           | metaeval/babi_nli                         | basic-coreference                             |                | babi_nli                                     | Classification      |
|  24 | babi_nli/three-arg-relations                                         | metaeval/babi_nli                         | three-arg-relations                           |                | babi_nli                                     | Classification      |
|  25 | babi_nli/yes-no-questions                                            | metaeval/babi_nli                         | yes-no-questions                              |                | babi_nli                                     | Classification      |
|  26 | babi_nli/path-finding                                                | metaeval/babi_nli                         | path-finding                                  |                | babi_nli                                     | Classification      |
|  27 | babi_nli/two-arg-relations                                           | metaeval/babi_nli                         | two-arg-relations                             |                | babi_nli                                     | Classification      |
|  28 | babi_nli/basic-induction                                             | metaeval/babi_nli                         | basic-induction                               |                | babi_nli                                     | Classification      |
|  29 | babi_nli/three-supporting-facts                                      | metaeval/babi_nli                         | three-supporting-facts                        |                | babi_nli                                     | Classification      |
|  30 | babi_nli/time-reasoning                                              | metaeval/babi_nli                         | time-reasoning                                |                | babi_nli                                     | Classification      |
|  31 | babi_nli/lists-sets                                                  | metaeval/babi_nli                         | lists-sets                                    |                | babi_nli                                     | Classification      |
|  32 | babi_nli/size-reasoning                                              | metaeval/babi_nli                         | size-reasoning                                |                | babi_nli                                     | Classification      |
|  33 | babi_nli/single-supporting-fact                                      | metaeval/babi_nli                         | single-supporting-fact                        |                | babi_nli                                     | Classification      |
|  34 | sick/label                                                           | sick                                      |                                               | label          | sick__label                                  | Classification      |
|  35 | sick/relatedness                                                     | sick                                      |                                               | relatedness    | sick__relatedness                            | Classification      |
|  36 | sick/entailment_AB                                                   | sick                                      |                                               | entailment_AB  | sick__entailment_AB                          | Classification      |
|  37 | snli                                                                 | snli                                      |                                               |                | snli                                         | Classification      |
|  38 | scitail/snli_format                                                  | scitail                                   | snli_format                                   |                | scitail                                      | Classification      |
|  39 | hans                                                                 | hans                                      |                                               |                | hans                                         | Classification      |
|  40 | WANLI                                                                | alisawuffles/WANLI                        |                                               |                | wanli                                        | Classification      |
|  41 | recast/recast_verbnet                                                | metaeval/recast                           | recast_verbnet                                |                | recast                                       | Classification      |
|  42 | recast/recast_ner                                                    | metaeval/recast                           | recast_ner                                    |                | recast                                       | Classification      |
|  43 | recast/recast_factuality                                             | metaeval/recast                           | recast_factuality                             |                | recast                                       | Classification      |
|  44 | recast/recast_puns                                                   | metaeval/recast                           | recast_puns                                   |                | recast                                       | Classification      |
|  45 | recast/recast_kg_relations                                           | metaeval/recast                           | recast_kg_relations                           |                | recast                                       | Classification      |
|  46 | recast/recast_sentiment                                              | metaeval/recast                           | recast_sentiment                              |                | recast                                       | Classification      |
|  47 | recast/recast_megaveridicality                                       | metaeval/recast                           | recast_megaveridicality                       |                | recast                                       | Classification      |
|  48 | recast/recast_verbcorner                                             | metaeval/recast                           | recast_verbcorner                             |                | recast                                       | Classification      |
|  49 | probability_words_nli/usnli                                          | sileod/probability_words_nli              | usnli                                         |                | probability_words_nli                        | Classification      |
|  50 | probability_words_nli/reasoning_2hop                                 | sileod/probability_words_nli              | reasoning_2hop                                |                | probability_words_nli                        | Classification      |
|  51 | probability_words_nli/reasoning_1hop                                 | sileod/probability_words_nli              | reasoning_1hop                                |                | probability_words_nli                        | Classification      |
|  52 | nan-nli/joey234--nan-nli                                             | joey234/nan-nli                           | joey234--nan-nli                              |                | nan_nli                                      | Classification      |
|  53 | nli_fever                                                            | pietrolesci/nli_fever                     |                                               |                | nli_fever                                    | Classification      |
|  54 | breaking_nli                                                         | pietrolesci/breaking_nli                  |                                               |                | breaking_nli                                 | Classification      |
|  55 | conj_nli                                                             | pietrolesci/conj_nli                      |                                               |                | conj_nli                                     | Classification      |
|  56 | fracas                                                               | pietrolesci/fracas                        |                                               |                | fracas                                       | Classification      |
|  57 | dialogue_nli                                                         | pietrolesci/dialogue_nli                  |                                               |                | dialogue_nli                                 | Classification      |
|  58 | mpe                                                                  | pietrolesci/mpe                           |                                               |                | mpe_nli                                      | Classification      |
|  59 | dnc                                                                  | pietrolesci/dnc                           |                                               |                | dnc_nli                                      | Classification      |
|  60 | gpt3_nli                                                             | pietrolesci/gpt3_nli                      |                                               |                | gpt3_nli                                     | Classification      |
|  61 | recast_white/fnplus                                                  | pietrolesci/recast_white                  |                                               | fnplus         | recast_white__fnplus                         | Classification      |
|  62 | recast_white/sprl                                                    | pietrolesci/recast_white                  |                                               | sprl           | recast_white__sprl                           | Classification      |
|  63 | recast_white/dpr                                                     | pietrolesci/recast_white                  |                                               | dpr            | recast_white__dpr                            | Classification      |
|  64 | joci                                                                 | pietrolesci/joci                          |                                               |                | joci                                         | Classification      |
|  65 | contrast_nli                                                         | martn-nguyen/contrast_nli                 |                                               |                | contrast_nli                                 | Classification      |
|  66 | robust_nli/IS_CS                                                     | pietrolesci/robust_nli                    |                                               | IS_CS          | robust_nli__IS_CS                            | Classification      |
|  67 | robust_nli/LI_LI                                                     | pietrolesci/robust_nli                    |                                               | LI_LI          | robust_nli__LI_LI                            | Classification      |
|  68 | robust_nli/ST_WO                                                     | pietrolesci/robust_nli                    |                                               | ST_WO          | robust_nli__ST_WO                            | Classification      |
|  69 | robust_nli/PI_SP                                                     | pietrolesci/robust_nli                    |                                               | PI_SP          | robust_nli__PI_SP                            | Classification      |
|  70 | robust_nli/PI_CD                                                     | pietrolesci/robust_nli                    |                                               | PI_CD          | robust_nli__PI_CD                            | Classification      |
|  71 | robust_nli/ST_SE                                                     | pietrolesci/robust_nli                    |                                               | ST_SE          | robust_nli__ST_SE                            | Classification      |
|  72 | robust_nli/ST_NE                                                     | pietrolesci/robust_nli                    |                                               | ST_NE          | robust_nli__ST_NE                            | Classification      |
|  73 | robust_nli/ST_LM                                                     | pietrolesci/robust_nli                    |                                               | ST_LM          | robust_nli__ST_LM                            | Classification      |
|  74 | robust_nli_is_sd                                                     | pietrolesci/robust_nli_is_sd              |                                               |                | robust_nli_is_sd                             | Classification      |
|  75 | robust_nli_li_ts                                                     | pietrolesci/robust_nli_li_ts              |                                               |                | robust_nli_li_ts                             | Classification      |
|  76 | gen_debiased_nli/snli_seq_z                                          | pietrolesci/gen_debiased_nli              |                                               | snli_seq_z     | gen_debiased_nli__snli_seq_z                 | Classification      |
|  77 | gen_debiased_nli/snli_z_aug                                          | pietrolesci/gen_debiased_nli              |                                               | snli_z_aug     | gen_debiased_nli__snli_z_aug                 | Classification      |
|  78 | gen_debiased_nli/snli_par_z                                          | pietrolesci/gen_debiased_nli              |                                               | snli_par_z     | gen_debiased_nli__snli_par_z                 | Classification      |
|  79 | gen_debiased_nli/mnli_par_z                                          | pietrolesci/gen_debiased_nli              |                                               | mnli_par_z     | gen_debiased_nli__mnli_par_z                 | Classification      |
|  80 | gen_debiased_nli/mnli_z_aug                                          | pietrolesci/gen_debiased_nli              |                                               | mnli_z_aug     | gen_debiased_nli__mnli_z_aug                 | Classification      |
|  81 | gen_debiased_nli/mnli_seq_z                                          | pietrolesci/gen_debiased_nli              |                                               | mnli_seq_z     | gen_debiased_nli__mnli_seq_z                 | Classification      |
|  82 | add_one_rte                                                          | pietrolesci/add_one_rte                   |                                               |                | add_one_rte                                  | Classification      |
|  83 | imppres/presupposition_change_of_state/presupposition                | metaeval/imppres                          | presupposition_change_of_state                | presupposition | imppres__presupposition                      | Classification      |
|  84 | imppres/presupposition_all_n_presupposition/presupposition           | metaeval/imppres                          | presupposition_all_n_presupposition           | presupposition | imppres__presupposition                      | Classification      |
|  85 | imppres/presupposition_question_presupposition/presupposition        | metaeval/imppres                          | presupposition_question_presupposition        | presupposition | imppres__presupposition                      | Classification      |
|  86 | imppres/presupposition_possessed_definites_uniqueness/presupposition | metaeval/imppres                          | presupposition_possessed_definites_uniqueness | presupposition | imppres__presupposition                      | Classification      |
|  87 | imppres/presupposition_possessed_definites_existence/presupposition  | metaeval/imppres                          | presupposition_possessed_definites_existence  | presupposition | imppres__presupposition                      | Classification      |
|  88 | imppres/presupposition_only_presupposition/presupposition            | metaeval/imppres                          | presupposition_only_presupposition            | presupposition | imppres__presupposition                      | Classification      |
|  89 | imppres/presupposition_cleft_uniqueness/presupposition               | metaeval/imppres                          | presupposition_cleft_uniqueness               | presupposition | imppres__presupposition                      | Classification      |
|  90 | imppres/presupposition_cleft_existence/presupposition                | metaeval/imppres                          | presupposition_cleft_existence                | presupposition | imppres__presupposition                      | Classification      |
|  91 | imppres/presupposition_both_presupposition/presupposition            | metaeval/imppres                          | presupposition_both_presupposition            | presupposition | imppres__presupposition                      | Classification      |
|  92 | imppres/implicature_quantifiers/prag                                 | metaeval/imppres                          | implicature_quantifiers                       | prag           | imppres__prag                                | Classification      |
|  93 | imppres/implicature_numerals_2_3/prag                                | metaeval/imppres                          | implicature_numerals_2_3                      | prag           | imppres__prag                                | Classification      |
|  94 | imppres/implicature_modals/prag                                      | metaeval/imppres                          | implicature_modals                            | prag           | imppres__prag                                | Classification      |
|  95 | imppres/implicature_numerals_10_100/prag                             | metaeval/imppres                          | implicature_numerals_10_100                   | prag           | imppres__prag                                | Classification      |
|  96 | imppres/implicature_gradable_adjective/prag                          | metaeval/imppres                          | implicature_gradable_adjective                | prag           | imppres__prag                                | Classification      |
|  97 | imppres/implicature_connectives/prag                                 | metaeval/imppres                          | implicature_connectives                       | prag           | imppres__prag                                | Classification      |
|  98 | imppres/implicature_gradable_verb/prag                               | metaeval/imppres                          | implicature_gradable_verb                     | prag           | imppres__prag                                | Classification      |
|  99 | imppres/implicature_quantifiers/log                                  | metaeval/imppres                          | implicature_quantifiers                       | log            | imppres__log                                 | Classification      |
| 100 | imppres/implicature_numerals_2_3/log                                 | metaeval/imppres                          | implicature_numerals_2_3                      | log            | imppres__log                                 | Classification      |
| 101 | imppres/implicature_numerals_10_100/log                              | metaeval/imppres                          | implicature_numerals_10_100                   | log            | imppres__log                                 | Classification      |
| 102 | imppres/implicature_modals/log                                       | metaeval/imppres                          | implicature_modals                            | log            | imppres__log                                 | Classification      |
| 103 | imppres/implicature_gradable_verb/log                                | metaeval/imppres                          | implicature_gradable_verb                     | log            | imppres__log                                 | Classification      |
| 104 | imppres/implicature_gradable_adjective/log                           | metaeval/imppres                          | implicature_gradable_adjective                | log            | imppres__log                                 | Classification      |
| 105 | imppres/implicature_connectives/log                                  | metaeval/imppres                          | implicature_connectives                       | log            | imppres__log                                 | Classification      |
| 106 | glue_diagnostics/diagnostics                                         | pietrolesci/glue_diagnostics              |                                               | diagnostics    | glue__diagnostics                            | Classification      |
| 107 | hlgd                                                                 | hlgd                                      |                                               |                | hlgd                                         | Classification      |
| 108 | paws/labeled_final                                                   | paws                                      | labeled_final                                 |                | paws___labeled_final                         | Classification      |
| 109 | paws/labeled_swap                                                    | paws                                      | labeled_swap                                  |                | paws___labeled_swap                          | Classification      |
| 110 | quora                                                                | quora                                     |                                               |                | quora                                        | Classification      |
| 111 | medical_questions_pairs                                              | medical_questions_pairs                   |                                               |                | medical_questions_pairs                      | Classification      |
| 112 | conll2003/pos_tags                                                   | conll2003                                 |                                               | pos_tags       | conll2003__pos_tags                          | TokenClassification |
| 113 | conll2003/chunk_tags                                                 | conll2003                                 |                                               | chunk_tags     | conll2003__chunk_tags                        | TokenClassification |
| 114 | conll2003/ner_tags                                                   | conll2003                                 |                                               | ner_tags       | conll2003__ner_tags                          | TokenClassification |
| 115 | hh-rlhf                                                              | Anthropic/hh-rlhf                         |                                               |                | anthropic_rlhf                               | MultipleChoice      |
| 116 | model-written-evals                                                  | Anthropic/model-written-evals             |                                               |                | model_written_evals                          | MultipleChoice      |
| 117 | truthful_qa/multiple_choice                                          | truthful_qa                               | multiple_choice                               |                | truthful_qa___multiple_choice                | MultipleChoice      |
| 118 | fig-qa                                                               | nightingal3/fig-qa                        |                                               |                | fig_qa                                       | MultipleChoice      |
| 119 | bigbench/anachronisms                                                | tasksource/bigbench                       | anachronisms                                  |                | bigbench                                     | MultipleChoice      |
| 120 | bigbench/identify_odd_metaphor                                       | tasksource/bigbench                       | identify_odd_metaphor                         |                | bigbench                                     | MultipleChoice      |
| 121 | bigbench/timedial                                                    | tasksource/bigbench                       | timedial                                      |                | bigbench                                     | MultipleChoice      |
| 122 | bigbench/emojis_emotion_prediction                                   | tasksource/bigbench                       | emojis_emotion_prediction                     |                | bigbench                                     | MultipleChoice      |
| 123 | bigbench/moral_permissibility                                        | tasksource/bigbench                       | moral_permissibility                          |                | bigbench                                     | MultipleChoice      |
| 124 | bigbench/dark_humor_detection                                        | tasksource/bigbench                       | dark_humor_detection                          |                | bigbench                                     | MultipleChoice      |
| 125 | bigbench/logical_deduction                                           | tasksource/bigbench                       | logical_deduction                             |                | bigbench                                     | MultipleChoice      |
| 126 | bigbench/crass_ai                                                    | tasksource/bigbench                       | crass_ai                                      |                | bigbench                                     | MultipleChoice      |
| 127 | bigbench/odd_one_out                                                 | tasksource/bigbench                       | odd_one_out                                   |                | bigbench                                     | MultipleChoice      |
| 128 | bigbench/suicide_risk                                                | tasksource/bigbench                       | suicide_risk                                  |                | bigbench                                     | MultipleChoice      |
| 129 | bigbench/contextual_parametric_knowledge_conflicts                   | tasksource/bigbench                       | contextual_parametric_knowledge_conflicts     |                | bigbench                                     | MultipleChoice      |
| 130 | bigbench/movie_dialog_same_or_different                              | tasksource/bigbench                       | movie_dialog_same_or_different                |                | bigbench                                     | MultipleChoice      |
| 131 | bigbench/entailed_polarity                                           | tasksource/bigbench                       | entailed_polarity                             |                | bigbench                                     | MultipleChoice      |
| 132 | bigbench/mathematical_induction                                      | tasksource/bigbench                       | mathematical_induction                        |                | bigbench                                     | MultipleChoice      |
| 133 | bigbench/metaphor_understanding                                      | tasksource/bigbench                       | metaphor_understanding                        |                | bigbench                                     | MultipleChoice      |
| 134 | bigbench/physical_intuition                                          | tasksource/bigbench                       | physical_intuition                            |                | bigbench                                     | MultipleChoice      |
| 135 | bigbench/hhh_alignment                                               | tasksource/bigbench                       | hhh_alignment                                 |                | bigbench                                     | MultipleChoice      |
| 136 | bigbench/nonsense_words_grammar                                      | tasksource/bigbench                       | nonsense_words_grammar                        |                | bigbench                                     | MultipleChoice      |
| 137 | bigbench/fantasy_reasoning                                           | tasksource/bigbench                       | fantasy_reasoning                             |                | bigbench                                     | MultipleChoice      |
| 138 | bigbench/ruin_names                                                  | tasksource/bigbench                       | ruin_names                                    |                | bigbench                                     | MultipleChoice      |
| 139 | bigbench/causal_judgment                                             | tasksource/bigbench                       | causal_judgment                               |                | bigbench                                     | MultipleChoice      |
| 140 | bigbench/cs_algorithms                                               | tasksource/bigbench                       | cs_algorithms                                 |                | bigbench                                     | MultipleChoice      |
| 141 | bigbench/sports_understanding                                        | tasksource/bigbench                       | sports_understanding                          |                | bigbench                                     | MultipleChoice      |
| 142 | bigbench/cause_and_effect                                            | tasksource/bigbench                       | cause_and_effect                              |                | bigbench                                     | MultipleChoice      |
| 143 | bigbench/implicatures                                                | tasksource/bigbench                       | implicatures                                  |                | bigbench                                     | MultipleChoice      |
| 144 | bigbench/logical_sequence                                            | tasksource/bigbench                       | logical_sequence                              |                | bigbench                                     | MultipleChoice      |
| 145 | bigbench/identify_math_theorems                                      | tasksource/bigbench                       | identify_math_theorems                        |                | bigbench                                     | MultipleChoice      |
| 146 | bigbench/riddle_sense                                                | tasksource/bigbench                       | riddle_sense                                  |                | bigbench                                     | MultipleChoice      |
| 147 | bigbench/cifar10_classification                                      | tasksource/bigbench                       | cifar10_classification                        |                | bigbench                                     | MultipleChoice      |
| 148 | bigbench/international_phonetic_alphabet_nli                         | tasksource/bigbench                       | international_phonetic_alphabet_nli           |                | bigbench                                     | MultipleChoice      |
| 149 | bigbench/metaphor_boolean                                            | tasksource/bigbench                       | metaphor_boolean                              |                | bigbench                                     | MultipleChoice      |
| 150 | bigbench/snarks                                                      | tasksource/bigbench                       | snarks                                        |                | bigbench                                     | MultipleChoice      |
| 151 | bigbench/mnist_ascii                                                 | tasksource/bigbench                       | mnist_ascii                                   |                | bigbench                                     | MultipleChoice      |
| 152 | bigbench/evaluating_information_essentiality                         | tasksource/bigbench                       | evaluating_information_essentiality           |                | bigbench                                     | MultipleChoice      |
| 153 | bigbench/figure_of_speech_detection                                  | tasksource/bigbench                       | figure_of_speech_detection                    |                | bigbench                                     | MultipleChoice      |
| 154 | bigbench/bbq_lite_json                                               | tasksource/bigbench                       | bbq_lite_json                                 |                | bigbench                                     | MultipleChoice      |
| 155 | bigbench/novel_concepts                                              | tasksource/bigbench                       | novel_concepts                                |                | bigbench                                     | MultipleChoice      |
| 156 | bigbench/checkmate_in_one                                            | tasksource/bigbench                       | checkmate_in_one                              |                | bigbench                                     | MultipleChoice      |
| 157 | bigbench/abstract_narrative_understanding                            | tasksource/bigbench                       | abstract_narrative_understanding              |                | bigbench                                     | MultipleChoice      |
| 158 | bigbench/epistemic_reasoning                                         | tasksource/bigbench                       | epistemic_reasoning                           |                | bigbench                                     | MultipleChoice      |
| 159 | bigbench/key_value_maps                                              | tasksource/bigbench                       | key_value_maps                                |                | bigbench                                     | MultipleChoice      |
| 160 | bigbench/analogical_similarity                                       | tasksource/bigbench                       | analogical_similarity                         |                | bigbench                                     | MultipleChoice      |
| 161 | bigbench/winowhy                                                     | tasksource/bigbench                       | winowhy                                       |                | bigbench                                     | MultipleChoice      |
| 162 | bigbench/similarities_abstraction                                    | tasksource/bigbench                       | similarities_abstraction                      |                | bigbench                                     | MultipleChoice      |
| 163 | bigbench/geometric_shapes                                            | tasksource/bigbench                       | geometric_shapes                              |                | bigbench                                     | MultipleChoice      |
| 164 | bigbench/discourse_marker_prediction                                 | tasksource/bigbench                       | discourse_marker_prediction                   |                | bigbench                                     | MultipleChoice      |
| 165 | bigbench/unit_interpretation                                         | tasksource/bigbench                       | unit_interpretation                           |                | bigbench                                     | MultipleChoice      |
| 166 | bigbench/goal_step_wikihow                                           | tasksource/bigbench                       | goal_step_wikihow                             |                | bigbench                                     | MultipleChoice      |
| 167 | bigbench/human_organs_senses                                         | tasksource/bigbench                       | human_organs_senses                           |                | bigbench                                     | MultipleChoice      |
| 168 | bigbench/authorship_verification                                     | tasksource/bigbench                       | authorship_verification                       |                | bigbench                                     | MultipleChoice      |
| 169 | bigbench/temporal_sequences                                          | tasksource/bigbench                       | temporal_sequences                            |                | bigbench                                     | MultipleChoice      |
| 170 | bigbench/arithmetic                                                  | tasksource/bigbench                       | arithmetic                                    |                | bigbench                                     | MultipleChoice      |
| 171 | bigbench/symbol_interpretation                                       | tasksource/bigbench                       | symbol_interpretation                         |                | bigbench                                     | MultipleChoice      |
| 172 | bigbench/english_proverbs                                            | tasksource/bigbench                       | english_proverbs                              |                | bigbench                                     | MultipleChoice      |
| 173 | bigbench/vitaminc_fact_verification                                  | tasksource/bigbench                       | vitaminc_fact_verification                    |                | bigbench                                     | MultipleChoice      |
| 174 | bigbench/gre_reading_comprehension                                   | tasksource/bigbench                       | gre_reading_comprehension                     |                | bigbench                                     | MultipleChoice      |
| 175 | bigbench/general_knowledge                                           | tasksource/bigbench                       | general_knowledge                             |                | bigbench                                     | MultipleChoice      |
| 176 | bigbench/penguins_in_a_table                                         | tasksource/bigbench                       | penguins_in_a_table                           |                | bigbench                                     | MultipleChoice      |
| 177 | bigbench/dyck_languages                                              | tasksource/bigbench                       | dyck_languages                                |                | bigbench                                     | MultipleChoice      |
| 178 | bigbench/understanding_fables                                        | tasksource/bigbench                       | understanding_fables                          |                | bigbench                                     | MultipleChoice      |
| 179 | bigbench/salient_translation_error_detection                         | tasksource/bigbench                       | salient_translation_error_detection           |                | bigbench                                     | MultipleChoice      |
| 180 | bigbench/formal_fallacies_syllogisms_negation                        | tasksource/bigbench                       | formal_fallacies_syllogisms_negation          |                | bigbench                                     | MultipleChoice      |
| 181 | bigbench/logic_grid_puzzle                                           | tasksource/bigbench                       | logic_grid_puzzle                             |                | bigbench                                     | MultipleChoice      |
| 182 | bigbench/logical_args                                                | tasksource/bigbench                       | logical_args                                  |                | bigbench                                     | MultipleChoice      |
| 183 | bigbench/undo_permutation                                            | tasksource/bigbench                       | undo_permutation                              |                | bigbench                                     | MultipleChoice      |
| 184 | bigbench/real_or_fake_text                                           | tasksource/bigbench                       | real_or_fake_text                             |                | bigbench                                     | MultipleChoice      |
| 185 | bigbench/sentence_ambiguity                                          | tasksource/bigbench                       | sentence_ambiguity                            |                | bigbench                                     | MultipleChoice      |
| 186 | bigbench/social_iqa                                                  | tasksource/bigbench                       | social_iqa                                    |                | bigbench                                     | MultipleChoice      |
| 187 | bigbench/physics                                                     | tasksource/bigbench                       | physics                                       |                | bigbench                                     | MultipleChoice      |
| 188 | bigbench/date_understanding                                          | tasksource/bigbench                       | date_understanding                            |                | bigbench                                     | MultipleChoice      |
| 189 | bigbench/logical_fallacy_detection                                   | tasksource/bigbench                       | logical_fallacy_detection                     |                | bigbench                                     | MultipleChoice      |
| 190 | bigbench/navigate                                                    | tasksource/bigbench                       | navigate                                      |                | bigbench                                     | MultipleChoice      |
| 191 | bigbench/crash_blossom                                               | tasksource/bigbench                       | crash_blossom                                 |                | bigbench                                     | MultipleChoice      |
| 192 | bigbench/hyperbaton                                                  | tasksource/bigbench                       | hyperbaton                                    |                | bigbench                                     | MultipleChoice      |
| 193 | bigbench/code_line_description                                       | tasksource/bigbench                       | code_line_description                         |                | bigbench                                     | MultipleChoice      |
| 194 | bigbench/intent_recognition                                          | tasksource/bigbench                       | intent_recognition                            |                | bigbench                                     | MultipleChoice      |
| 195 | bigbench/presuppositions_as_nli                                      | tasksource/bigbench                       | presuppositions_as_nli                        |                | bigbench                                     | MultipleChoice      |
| 196 | bigbench/color                                                       | tasksource/bigbench                       | color                                         |                | bigbench                                     | MultipleChoice      |
| 197 | bigbench/fact_checker                                                | tasksource/bigbench                       | fact_checker                                  |                | bigbench                                     | MultipleChoice      |
| 198 | bigbench/play_dialog_same_or_different                               | tasksource/bigbench                       | play_dialog_same_or_different                 |                | bigbench                                     | MultipleChoice      |
| 199 | bigbench/phrase_relatedness                                          | tasksource/bigbench                       | phrase_relatedness                            |                | bigbench                                     | MultipleChoice      |
| 200 | bigbench/conceptual_combinations                                     | tasksource/bigbench                       | conceptual_combinations                       |                | bigbench                                     | MultipleChoice      |
| 201 | bigbench/strategyqa                                                  | tasksource/bigbench                       | strategyqa                                    |                | bigbench                                     | MultipleChoice      |
| 202 | bigbench/tracking_shuffled_objects                                   | tasksource/bigbench                       | tracking_shuffled_objects                     |                | bigbench                                     | MultipleChoice      |
| 203 | bigbench/implicit_relations                                          | tasksource/bigbench                       | implicit_relations                            |                | bigbench                                     | MultipleChoice      |
| 204 | bigbench/reasoning_about_colored_objects                             | tasksource/bigbench                       | reasoning_about_colored_objects               |                | bigbench                                     | MultipleChoice      |
| 205 | bigbench/irony_identification                                        | tasksource/bigbench                       | irony_identification                          |                | bigbench                                     | MultipleChoice      |
| 206 | bigbench/emoji_movie                                                 | tasksource/bigbench                       | emoji_movie                                   |                | bigbench                                     | MultipleChoice      |
| 207 | bigbench/simple_ethical_questions                                    | tasksource/bigbench                       | simple_ethical_questions                      |                | bigbench                                     | MultipleChoice      |
| 208 | bigbench/empirical_judgments                                         | tasksource/bigbench                       | empirical_judgments                           |                | bigbench                                     | MultipleChoice      |
| 209 | bigbench/disambiguation_qa                                           | tasksource/bigbench                       | disambiguation_qa                             |                | bigbench                                     | MultipleChoice      |
| 210 | bigbench/movie_recommendation                                        | tasksource/bigbench                       | movie_recommendation                          |                | bigbench                                     | MultipleChoice      |
| 211 | bigbench/misconceptions                                              | tasksource/bigbench                       | misconceptions                                |                | bigbench                                     | MultipleChoice      |
| 212 | bigbench/question_selection                                          | tasksource/bigbench                       | question_selection                            |                | bigbench                                     | MultipleChoice      |
| 213 | bigbench/social_support                                              | tasksource/bigbench                       | social_support                                |                | bigbench                                     | MultipleChoice      |
| 214 | bigbench/analytic_entailment                                         | tasksource/bigbench                       | analytic_entailment                           |                | bigbench                                     | MultipleChoice      |
| 215 | bigbench/hindu_knowledge                                             | tasksource/bigbench                       | hindu_knowledge                               |                | bigbench                                     | MultipleChoice      |
| 216 | bigbench/strange_stories                                             | tasksource/bigbench                       | strange_stories                               |                | bigbench                                     | MultipleChoice      |
| 217 | bigbench/elementary_math_qa                                          | tasksource/bigbench                       | elementary_math_qa                            |                | bigbench                                     | MultipleChoice      |
| 218 | bigbench/known_unknowns                                              | tasksource/bigbench                       | known_unknowns                                |                | bigbench                                     | MultipleChoice      |
| 241 | cos_e/v1.0                                                           | cos_e                                     | v1.0                                          |                | cos_e                                        | MultipleChoice      |
| 242 | cosmos_qa                                                            | cosmos_qa                                 |                                               |                | cosmos_qa                                    | MultipleChoice      |
| 243 | dream                                                                | dream                                     |                                               |                | dream                                        | MultipleChoice      |
| 244 | openbookqa                                                           | openbookqa                                |                                               |                | openbookqa                                   | MultipleChoice      |
| 245 | qasc                                                                 | qasc                                      |                                               |                | qasc                                         | MultipleChoice      |
| 246 | quartz                                                               | quartz                                    |                                               |                | quartz                                       | MultipleChoice      |
| 247 | quail                                                                | quail                                     |                                               |                | quail                                        | MultipleChoice      |
| 248 | head_qa/en                                                           | head_qa                                   | en                                            |                | head_qa___en                                 | MultipleChoice      |
| 249 | sciq                                                                 | sciq                                      |                                               |                | sciq                                         | MultipleChoice      |
| 250 | social_i_qa                                                          | social_i_qa                               |                                               |                | social_i_qa                                  | MultipleChoice      |
| 251 | wiki_hop                                                             | wiki_hop                                  |                                               |                | wiki_hop                                     | MultipleChoice      |
| 252 | wiqa                                                                 | wiqa                                      |                                               |                | wiqa                                         | MultipleChoice      |
| 253 | piqa                                                                 | piqa                                      |                                               |                | piqa                                         | MultipleChoice      |
| 254 | hellaswag                                                            | hellaswag                                 |                                               |                | hellaswag                                    | MultipleChoice      |
| 255 | super_glue/copa                                                      | super_glue                                | copa                                          |                | super_glue___copa                            | MultipleChoice      |
| 256 | balanced-copa                                                        | pkavumba/balanced-copa                    |                                               |                | balanced_copa                                | MultipleChoice      |
| 257 | e-CARE                                                               | 12ml/e-CARE                               |                                               |                | e_care                                       | MultipleChoice      |
| 258 | art                                                                  | art                                       |                                               |                | art                                          | MultipleChoice      |
| 259 | mmlu/high_school_chemistry                                           | tasksource/mmlu                           | high_school_chemistry                         |                | mmlu                                         | MultipleChoice      |
| 260 | mmlu/high_school_computer_science                                    | tasksource/mmlu                           | high_school_computer_science                  |                | mmlu                                         | MultipleChoice      |
| 261 | mmlu/high_school_european_history                                    | tasksource/mmlu                           | high_school_european_history                  |                | mmlu                                         | MultipleChoice      |
| 262 | mmlu/logical_fallacies                                               | tasksource/mmlu                           | logical_fallacies                             |                | mmlu                                         | MultipleChoice      |
| 263 | mmlu/high_school_geography                                           | tasksource/mmlu                           | high_school_geography                         |                | mmlu                                         | MultipleChoice      |
| 264 | mmlu/high_school_government_and_politics                             | tasksource/mmlu                           | high_school_government_and_politics           |                | mmlu                                         | MultipleChoice      |
| 265 | mmlu/high_school_macroeconomics                                      | tasksource/mmlu                           | high_school_macroeconomics                    |                | mmlu                                         | MultipleChoice      |
| 266 | mmlu/high_school_biology                                             | tasksource/mmlu                           | high_school_biology                           |                | mmlu                                         | MultipleChoice      |
| 267 | mmlu/global_facts                                                    | tasksource/mmlu                           | global_facts                                  |                | mmlu                                         | MultipleChoice      |
| 268 | mmlu/formal_logic                                                    | tasksource/mmlu                           | formal_logic                                  |                | mmlu                                         | MultipleChoice      |
| 269 | mmlu/elementary_mathematics                                          | tasksource/mmlu                           | elementary_mathematics                        |                | mmlu                                         | MultipleChoice      |
| 270 | mmlu/electrical_engineering                                          | tasksource/mmlu                           | electrical_engineering                        |                | mmlu                                         | MultipleChoice      |
| 271 | mmlu/econometrics                                                    | tasksource/mmlu                           | econometrics                                  |                | mmlu                                         | MultipleChoice      |
| 272 | mmlu/conceptual_physics                                              | tasksource/mmlu                           | conceptual_physics                            |                | mmlu                                         | MultipleChoice      |
| 273 | mmlu/computer_security                                               | tasksource/mmlu                           | computer_security                             |                | mmlu                                         | MultipleChoice      |
| 274 | mmlu/abstract_algebra                                                | tasksource/mmlu                           | abstract_algebra                              |                | mmlu                                         | MultipleChoice      |
| 275 | mmlu/anatomy                                                         | tasksource/mmlu                           | anatomy                                       |                | mmlu                                         | MultipleChoice      |
| 276 | mmlu/astronomy                                                       | tasksource/mmlu                           | astronomy                                     |                | mmlu                                         | MultipleChoice      |
| 277 | mmlu/business_ethics                                                 | tasksource/mmlu                           | business_ethics                               |                | mmlu                                         | MultipleChoice      |
| 278 | mmlu/clinical_knowledge                                              | tasksource/mmlu                           | clinical_knowledge                            |                | mmlu                                         | MultipleChoice      |
| 279 | mmlu/college_biology                                                 | tasksource/mmlu                           | college_biology                               |                | mmlu                                         | MultipleChoice      |
| 280 | mmlu/college_chemistry                                               | tasksource/mmlu                           | college_chemistry                             |                | mmlu                                         | MultipleChoice      |
| 281 | mmlu/college_computer_science                                        | tasksource/mmlu                           | college_computer_science                      |                | mmlu                                         | MultipleChoice      |
| 282 | mmlu/college_mathematics                                             | tasksource/mmlu                           | college_mathematics                           |                | mmlu                                         | MultipleChoice      |
| 283 | mmlu/high_school_mathematics                                         | tasksource/mmlu                           | high_school_mathematics                       |                | mmlu                                         | MultipleChoice      |
| 284 | mmlu/jurisprudence                                                   | tasksource/mmlu                           | jurisprudence                                 |                | mmlu                                         | MultipleChoice      |
| 285 | mmlu/world_religions                                                 | tasksource/mmlu                           | world_religions                               |                | mmlu                                         | MultipleChoice      |
| 286 | mmlu/high_school_microeconomics                                      | tasksource/mmlu                           | high_school_microeconomics                    |                | mmlu                                         | MultipleChoice      |
| 287 | mmlu/college_medicine                                                | tasksource/mmlu                           | college_medicine                              |                | mmlu                                         | MultipleChoice      |
| 288 | mmlu/machine_learning                                                | tasksource/mmlu                           | machine_learning                              |                | mmlu                                         | MultipleChoice      |
| 289 | mmlu/management                                                      | tasksource/mmlu                           | management                                    |                | mmlu                                         | MultipleChoice      |
| 290 | mmlu/marketing                                                       | tasksource/mmlu                           | marketing                                     |                | mmlu                                         | MultipleChoice      |
| 291 | mmlu/medical_genetics                                                | tasksource/mmlu                           | medical_genetics                              |                | mmlu                                         | MultipleChoice      |
| 292 | mmlu/miscellaneous                                                   | tasksource/mmlu                           | miscellaneous                                 |                | mmlu                                         | MultipleChoice      |
| 293 | mmlu/moral_disputes                                                  | tasksource/mmlu                           | moral_disputes                                |                | mmlu                                         | MultipleChoice      |
| 294 | mmlu/moral_scenarios                                                 | tasksource/mmlu                           | moral_scenarios                               |                | mmlu                                         | MultipleChoice      |
| 295 | mmlu/nutrition                                                       | tasksource/mmlu                           | nutrition                                     |                | mmlu                                         | MultipleChoice      |
| 296 | mmlu/philosophy                                                      | tasksource/mmlu                           | philosophy                                    |                | mmlu                                         | MultipleChoice      |
| 297 | mmlu/prehistory                                                      | tasksource/mmlu                           | prehistory                                    |                | mmlu                                         | MultipleChoice      |
| 298 | mmlu/professional_accounting                                         | tasksource/mmlu                           | professional_accounting                       |                | mmlu                                         | MultipleChoice      |
| 299 | mmlu/professional_law                                                | tasksource/mmlu                           | professional_law                              |                | mmlu                                         | MultipleChoice      |
| 300 | mmlu/professional_medicine                                           | tasksource/mmlu                           | professional_medicine                         |                | mmlu                                         | MultipleChoice      |
| 301 | mmlu/virology                                                        | tasksource/mmlu                           | virology                                      |                | mmlu                                         | MultipleChoice      |
| 302 | mmlu/professional_psychology                                         | tasksource/mmlu                           | professional_psychology                       |                | mmlu                                         | MultipleChoice      |
| 303 | mmlu/public_relations                                                | tasksource/mmlu                           | public_relations                              |                | mmlu                                         | MultipleChoice      |
| 304 | mmlu/high_school_physics                                             | tasksource/mmlu                           | high_school_physics                           |                | mmlu                                         | MultipleChoice      |
| 305 | mmlu/us_foreign_policy                                               | tasksource/mmlu                           | us_foreign_policy                             |                | mmlu                                         | MultipleChoice      |
| 306 | mmlu/high_school_psychology                                          | tasksource/mmlu                           | high_school_psychology                        |                | mmlu                                         | MultipleChoice      |
| 307 | mmlu/high_school_statistics                                          | tasksource/mmlu                           | high_school_statistics                        |                | mmlu                                         | MultipleChoice      |
| 308 | mmlu/high_school_us_history                                          | tasksource/mmlu                           | high_school_us_history                        |                | mmlu                                         | MultipleChoice      |
| 309 | mmlu/high_school_world_history                                       | tasksource/mmlu                           | high_school_world_history                     |                | mmlu                                         | MultipleChoice      |
| 310 | mmlu/international_law                                               | tasksource/mmlu                           | international_law                             |                | mmlu                                         | MultipleChoice      |
| 311 | mmlu/human_aging                                                     | tasksource/mmlu                           | human_aging                                   |                | mmlu                                         | MultipleChoice      |
| 312 | mmlu/sociology                                                       | tasksource/mmlu                           | sociology                                     |                | mmlu                                         | MultipleChoice      |
| 313 | mmlu/human_sexuality                                                 | tasksource/mmlu                           | human_sexuality                               |                | mmlu                                         | MultipleChoice      |
| 314 | mmlu/security_studies                                                | tasksource/mmlu                           | security_studies                              |                | mmlu                                         | MultipleChoice      |
| 315 | mmlu/college_physics                                                 | tasksource/mmlu                           | college_physics                               |                | mmlu                                         | MultipleChoice      |
| 316 | winogrande/winogrande_xl                                             | winogrande                                | winogrande_xl                                 |                | winogrande                                   | MultipleChoice      |
| 317 | codah/codah                                                          | codah                                     | codah                                         |                | codah                                        | MultipleChoice      |
| 318 | ai2_arc/ARC-Easy/challenge                                           | ai2_arc                                   | ARC-Easy                                      | challenge      | ai2_arc__challenge                           | MultipleChoice      |
| 319 | ai2_arc/ARC-Challenge/challenge                                      | ai2_arc                                   | ARC-Challenge                                 | challenge      | ai2_arc__challenge                           | MultipleChoice      |
| 320 | definite_pronoun_resolution                                          | definite_pronoun_resolution               |                                               |                | definite_pronoun_resolution                  | MultipleChoice      |
| 321 | swag                                                                 | swag                                      |                                               |                | swag                                         | MultipleChoice      |
| 322 | math_qa                                                              | math_qa                                   |                                               |                | math_qa                                      | MultipleChoice      |
| 323 | glue/cola                                                            | glue                                      | cola                                          |                | glue___cola                                  | Classification      |
| 324 | glue/sst2                                                            | glue                                      | sst2                                          |                | glue___sst2                                  | Classification      |
| 325 | utilitarianism                                                       | metaeval/utilitarianism                   |                                               |                | utilitarianism                               | Classification      |
| 326 | amazon_counterfactual/en                                             | mteb/amazon_counterfactual                | en                                            |                | amazon_counterfactual                        | Classification      |
| 327 | insincere-questions                                                  | SetFit/insincere-questions                |                                               |                | insincere_questions                          | Classification      |
| 328 | toxic_conversations                                                  | SetFit/toxic_conversations                |                                               |                | toxic_conversations                          | Classification      |
| 329 | TuringBench                                                          | turingbench/TuringBench                   |                                               |                | turingbench                                  | Classification      |
| 330 | trec                                                                 | trec                                      |                                               |                | trec                                         | Classification      |
| 331 | vitaminc/tals--vitaminc                                              | tals/vitaminc                             | tals--vitaminc                                |                | tals_vitaminc                                | Classification      |
| 332 | hope_edi/english                                                     | hope_edi                                  | english                                       |                | hope_edi                                     | Classification      |
| 333 | rumoureval_2019/RumourEval2019                                       | strombergnlp/rumoureval_2019              | RumourEval2019                                |                | rumoureval_2019                              | Classification      |
| 334 | ethos/binary                                                         | ethos                                     | binary                                        |                | ethos___binary                               | Classification      |
| 335 | ethos/multilabel                                                     | ethos                                     | multilabel                                    |                | ethos___multilabel                           | Classification      |
| 336 | tweet_eval/emoji                                                     | tweet_eval                                | emoji                                         |                | tweet_eval                                   | Classification      |
| 337 | tweet_eval/emotion                                                   | tweet_eval                                | emotion                                       |                | tweet_eval                                   | Classification      |
| 338 | tweet_eval/hate                                                      | tweet_eval                                | hate                                          |                | tweet_eval                                   | Classification      |
| 339 | tweet_eval/offensive                                                 | tweet_eval                                | offensive                                     |                | tweet_eval                                   | Classification      |
| 340 | tweet_eval/sentiment                                                 | tweet_eval                                | sentiment                                     |                | tweet_eval                                   | Classification      |
| 341 | tweet_eval/irony                                                     | tweet_eval                                | irony                                         |                | tweet_eval                                   | Classification      |
| 342 | tweet_eval/stance_atheism                                            | tweet_eval                                | stance_atheism                                |                | tweet_eval                                   | Classification      |
| 343 | tweet_eval/stance_climate                                            | tweet_eval                                | stance_climate                                |                | tweet_eval                                   | Classification      |
| 344 | tweet_eval/stance_hillary                                            | tweet_eval                                | stance_hillary                                |                | tweet_eval                                   | Classification      |
| 345 | tweet_eval/stance_feminist                                           | tweet_eval                                | stance_feminist                               |                | tweet_eval                                   | Classification      |
| 346 | tweet_eval/stance_abortion                                           | tweet_eval                                | stance_abortion                               |                | tweet_eval                                   | Classification      |
| 347 | discovery/discovery                                                  | discovery                                 | discovery                                     |                | discovery                                    | Classification      |
| 368 | silicone/maptask                                                     | silicone                                  | maptask                                       |                | silicone                                     | Classification      |
| 369 | silicone/oasis                                                       | silicone                                  | oasis                                         |                | silicone                                     | Classification      |
| 370 | silicone/meld_s                                                      | silicone                                  | meld_s                                        |                | silicone                                     | Classification      |
| 371 | silicone/meld_e                                                      | silicone                                  | meld_e                                        |                | silicone                                     | Classification      |
| 372 | silicone/iemocap                                                     | silicone                                  | iemocap                                       |                | silicone                                     | Classification      |
| 373 | silicone/dyda_e                                                      | silicone                                  | dyda_e                                        |                | silicone                                     | Classification      |
| 374 | silicone/dyda_da                                                     | silicone                                  | dyda_da                                       |                | silicone                                     | Classification      |
| 375 | silicone/sem                                                         | silicone                                  | sem                                           |                | silicone                                     | Classification      |
| 376 | lex_glue/eurlex                                                      | lex_glue                                  | eurlex                                        |                | lex_glue___eurlex                            | Classification      |
| 377 | lex_glue/scotus                                                      | lex_glue                                  | scotus                                        |                | lex_glue___scotus                            | Classification      |
| 378 | lex_glue/ledgar                                                      | lex_glue                                  | ledgar                                        |                | lex_glue___ledgar                            | Classification      |
| 379 | lex_glue/unfair_tos                                                  | lex_glue                                  | unfair_tos                                    |                | lex_glue___unfair_tos                        | Classification      |
| 380 | lex_glue/case_hold                                                   | lex_glue                                  | case_hold                                     |                | lex_glue___case_hold                         | MultipleChoice      |
| 381 | language-identification                                              | papluca/language-identification           |                                               |                | language_identification                      | Classification      |
| 382 | imdb                                                                 | imdb                                      |                                               |                | imdb                                         | Classification      |
| 383 | rotten_tomatoes                                                      | rotten_tomatoes                           |                                               |                | rotten_tomatoes                              | Classification      |
| 384 | ag_news                                                              | ag_news                                   |                                               |                | ag_news                                      | Classification      |
| 385 | yelp_review_full/yelp_review_full                                    | yelp_review_full                          | yelp_review_full                              |                | yelp_review_full                             | Classification      |
| 386 | financial_phrasebank/sentences_allagree                              | financial_phrasebank                      | sentences_allagree                            |                | financial_phrasebank                         | Classification      |
| 387 | poem_sentiment                                                       | poem_sentiment                            |                                               |                | poem_sentiment                               | Classification      |
| 388 | dbpedia_14/dbpedia_14                                                | dbpedia_14                                | dbpedia_14                                    |                | dbpedia_14                                   | Classification      |
| 389 | amazon_polarity/amazon_polarity                                      | amazon_polarity                           | amazon_polarity                               |                | amazon_polarity                              | Classification      |
| 390 | app_reviews                                                          | app_reviews                               |                                               |                | app_reviews                                  | Classification      |
| 391 | hate_speech18                                                        | hate_speech18                             |                                               |                | hate_speech18                                | Classification      |
| 392 | sms_spam                                                             | sms_spam                                  |                                               |                | sms_spam                                     | Classification      |
| 393 | humicroedit/subtask-1                                                | humicroedit                               | subtask-1                                     |                | humicroedit___subtask_1                      | Classification      |
| 394 | humicroedit/subtask-2                                                | humicroedit                               | subtask-2                                     |                | humicroedit___subtask_2                      | Classification      |
| 395 | snips_built_in_intents                                               | snips_built_in_intents                    |                                               |                | snips_built_in_intents                       | Classification      |
| 396 | banking77                                                            | banking77                                 |                                               |                | banking77                                    | Classification      |
| 397 | hate_speech_offensive                                                | hate_speech_offensive                     |                                               |                | hate_speech_offensive                        | Classification      |
| 398 | yahoo_answers_topics                                                 | yahoo_answers_topics                      |                                               |                | yahoo_answers_topics                         | Classification      |
| 399 | stackoverflow-questions                                              | pacovaldez/stackoverflow-questions        |                                               |                | stackoverflow_questions                      | Classification      |
| 400 | hyperpartisan_news                                                   | zapsdcn/hyperpartisan_news                |                                               |                | hyperpartisan_news                           | Classification      |
| 401 | sciie                                                                | zapsdcn/sciie                             |                                               |                | scierc                                       | Classification      |
| 402 | citation_intent                                                      | zapsdcn/citation_intent                   |                                               |                | citation_intent                              | Classification      |
| 403 | go_emotions/simplified                                               | go_emotions                               | simplified                                    |                | go_emotions___simplified                     | Classification      |
| 404 | scicite                                                              | scicite                                   |                                               |                | scicite                                      | Classification      |
| 405 | liar                                                                 | liar                                      |                                               |                | liar                                         | Classification      |
| 406 | lexical_relation_classification/EVALution                            | relbert/lexical_relation_classification   | EVALution                                     |                | relbert_lexical_relation_classification      | Classification      |
| 407 | lexical_relation_classification/BLESS                                | relbert/lexical_relation_classification   | BLESS                                         |                | relbert_lexical_relation_classification      | Classification      |
| 408 | lexical_relation_classification/CogALexV                             | relbert/lexical_relation_classification   | CogALexV                                      |                | relbert_lexical_relation_classification      | Classification      |
| 409 | lexical_relation_classification/ROOT09                               | relbert/lexical_relation_classification   | ROOT09                                        |                | relbert_lexical_relation_classification      | Classification      |
| 410 | lexical_relation_classification/K&H+N                                | relbert/lexical_relation_classification   | K&H+N                                         |                | relbert_lexical_relation_classification      | Classification      |
| 411 | linguisticprobing/bigram_shift                                       | metaeval/linguisticprobing                | bigram_shift                                  |                | metaeval_linguisticprobing                   | Classification      |
| 412 | linguisticprobing/odd_man_out                                        | metaeval/linguisticprobing                | odd_man_out                                   |                | metaeval_linguisticprobing                   | Classification      |
| 413 | linguisticprobing/sentence_length                                    | metaeval/linguisticprobing                | sentence_length                               |                | metaeval_linguisticprobing                   | Classification      |
| 414 | linguisticprobing/coordination_inversion                             | metaeval/linguisticprobing                | coordination_inversion                        |                | metaeval_linguisticprobing                   | Classification      |
| 415 | linguisticprobing/tree_depth                                         | metaeval/linguisticprobing                | tree_depth                                    |                | metaeval_linguisticprobing                   | Classification      |
| 416 | linguisticprobing/subj_number                                        | metaeval/linguisticprobing                | subj_number                                   |                | metaeval_linguisticprobing                   | Classification      |
| 417 | linguisticprobing/obj_number                                         | metaeval/linguisticprobing                | obj_number                                    |                | metaeval_linguisticprobing                   | Classification      |
| 418 | linguisticprobing/past_present                                       | metaeval/linguisticprobing                | past_present                                  |                | metaeval_linguisticprobing                   | Classification      |
| 419 | linguisticprobing/top_constituents                                   | metaeval/linguisticprobing                | top_constituents                              |                | metaeval_linguisticprobing                   | Classification      |
| 420 | crowdflower/sentiment_nuclear_power                                  | metaeval/crowdflower                      | sentiment_nuclear_power                       |                | metaeval_crowdflower                         | Classification      |
| 421 | crowdflower/tweet_global_warming                                     | metaeval/crowdflower                      | tweet_global_warming                          |                | metaeval_crowdflower                         | Classification      |
| 422 | crowdflower/airline-sentiment                                        | metaeval/crowdflower                      | airline-sentiment                             |                | metaeval_crowdflower                         | Classification      |
| 423 | crowdflower/corporate-messaging                                      | metaeval/crowdflower                      | corporate-messaging                           |                | metaeval_crowdflower                         | Classification      |
| 424 | crowdflower/economic-news                                            | metaeval/crowdflower                      | economic-news                                 |                | metaeval_crowdflower                         | Classification      |
| 425 | crowdflower/political-media-bias                                     | metaeval/crowdflower                      | political-media-bias                          |                | metaeval_crowdflower                         | Classification      |
| 426 | crowdflower/political-media-audience                                 | metaeval/crowdflower                      | political-media-audience                      |                | metaeval_crowdflower                         | Classification      |
| 427 | crowdflower/political-media-message                                  | metaeval/crowdflower                      | political-media-message                       |                | metaeval_crowdflower                         | Classification      |
| 428 | crowdflower/text_emotion                                             | metaeval/crowdflower                      | text_emotion                                  |                | metaeval_crowdflower                         | Classification      |
| 429 | ethics/commonsense                                                   | metaeval/ethics                           | commonsense                                   |                | metaeval_ethics___commonsense                | Classification      |
| 430 | ethics/deontology                                                    | metaeval/ethics                           | deontology                                    |                | metaeval_ethics___deontology                 | Classification      |
| 431 | ethics/justice                                                       | metaeval/ethics                           | justice                                       |                | metaeval_ethics___justice                    | Classification      |
| 432 | ethics/virtue                                                        | metaeval/ethics                           | virtue                                        |                | metaeval_ethics___virtue                     | Classification      |
| 433 | emo/emo2019                                                          | emo                                       | emo2019                                       |                | emo                                          | Classification      |
| 434 | google_wellformed_query                                              | google_wellformed_query                   |                                               |                | google_wellformed_query                      | Classification      |
| 435 | tweets_hate_speech_detection                                         | tweets_hate_speech_detection              |                                               |                | tweets_hate_speech_detection                 | Classification      |
| 436 | has_part                                                             | has_part                                  |                                               |                | has_part                                     | Classification      |
| 437 | wnut_17/wnut_17                                                      | wnut_17                                   | wnut_17                                       |                | wnut_17                                      | TokenClassification |
| 438 | ncbi_disease/ncbi_disease                                            | ncbi_disease                              | ncbi_disease                                  |                | ncbi_disease                                 | TokenClassification |
| 439 | acronym_identification                                               | acronym_identification                    |                                               |                | acronym_identification                       | TokenClassification |
| 440 | jnlpba/jnlpba                                                        | jnlpba                                    | jnlpba                                        |                | jnlpba                                       | TokenClassification |
| 441 | species_800/species_800                                              | species_800                               | species_800                                   |                | species_800                                  | TokenClassification |
| 442 | ontonotes_english/SpeedOfMagic--ontonotes_english                    | SpeedOfMagic/ontonotes_english            | SpeedOfMagic--ontonotes_english               |                | SpeedOfMagic_ontonotes_english               | TokenClassification |
| 443 | blog_authorship_corpus/gender                                        | blog_authorship_corpus                    |                                               | gender         | blog_authorship_corpus__gender               | Classification      |
| 444 | blog_authorship_corpus/age                                           | blog_authorship_corpus                    |                                               | age            | blog_authorship_corpus__age                  | Classification      |
| 445 | blog_authorship_corpus/horoscope                                     | blog_authorship_corpus                    |                                               | horoscope      | blog_authorship_corpus__horoscope            | Classification      |
| 446 | blog_authorship_corpus/job                                           | blog_authorship_corpus                    |                                               | job            | blog_authorship_corpus__job                  | Classification      |
| 447 | open_question_type                                                   | launch/open_question_type                 |                                               |                | launch_open_question_type                    | Classification      |
| 448 | health_fact                                                          | health_fact                               |                                               |                | health_fact                                  | Classification      |
| 449 | commonsense_qa                                                       | commonsense_qa                            |                                               |                | commonsense_qa                               | MultipleChoice      |
| 450 | mc_taco                                                              | mc_taco                                   |                                               |                | mc_taco                                      | Classification      |
| 451 | ade_corpus_v2/Ade_corpus_v2_classification                           | ade_corpus_v2                             | Ade_corpus_v2_classification                  |                | ade_corpus_v2___Ade_corpus_v2_classification | Classification      |
| 452 | discosense                                                           | prajjwal1/discosense                      |                                               |                | discosense                                   | MultipleChoice      |
| 453 | circa                                                                | circa                                     |                                               |                | circa                                        | Classification      |
| 454 | EffectiveFeedbackStudentWriting                                      | YaHi/EffectiveFeedbackStudentWriting      |                                               |                | effective_feedback_student_writing           | Classification      |
| 455 | promptSentiment                                                      | Ericwang/promptSentiment                  |                                               |                | promptSentiment                              | Classification      |
| 456 | promptNLI                                                            | Ericwang/promptNLI                        |                                               |                | promptNLI                                    | Classification      |
| 457 | promptSpoke                                                          | Ericwang/promptSpoke                      |                                               |                | promptSpoke                                  | Classification      |
| 458 | promptProficiency                                                    | Ericwang/promptProficiency                |                                               |                | promptProficiency                            | Classification      |
| 459 | promptGrammar                                                        | Ericwang/promptGrammar                    |                                               |                | promptGrammar                                | Classification      |
| 460 | promptCoherence                                                      | Ericwang/promptCoherence                  |                                               |                | promptCoherence                              | Classification      |
| 461 | phrase_similarity                                                    | PiC/phrase_similarity                     |                                               |                | phrase_similarity                            | Classification      |
| 462 | scientific-exaggeration-detection                                    | copenlu/scientific-exaggeration-detection |                                               |                | exaggeration_detection                       | Classification      |
| 463 | quarel                                                               | quarel                                    |                                               |                | quarel                                       | Classification      |
| 464 | fever-evidence-related/mwong--fever-related                          | mwong/fever-evidence-related              | mwong--fever-related                          |                | mwong_fever_evidence_related                 | Classification      |
| 465 | numer_sense                                                          | numer_sense                               |                                               |                | numer_sense                                  | Classification      |
| 466 | dynasent/dynabench.dynasent.r1.all/r1                                | dynabench/dynasent                        | dynabench.dynasent.r1.all                     | r1             | dynasent__r1                                 | Classification      |
| 467 | dynasent/dynabench.dynasent.r2.all/r2                                | dynabench/dynasent                        | dynabench.dynasent.r2.all                     | r2             | dynasent__r2                                 | Classification      |
| 468 | Sarcasm_News_Headline                                                | raquiba/Sarcasm_News_Headline             |                                               |                | sarcasm_news                                 | Classification      |
| 469 | sem_eval_2010_task_8                                                 | sem_eval_2010_task_8                      |                                               |                | sem_eval_2010_task_8                         | Classification      |
| 470 | auditor_review/demo-org--auditor_review                              | demo-org/auditor_review                   | demo-org--auditor_review                      |                | demo_org_auditor_review                      | Classification      |
| 471 | medmcqa                                                              | medmcqa                                   |                                               |                | medmcqa                                      | MultipleChoice      |
| 472 | aqua_rat/tokenized                                                   | aqua_rat                                  | tokenized                                     |                | aqua_rat___tokenized                         | MultipleChoice      |
| 473 | Dynasent_Disagreement                                                | RuyuanWan/Dynasent_Disagreement           |                                               |                | dynasent_disagreement                        | Classification      |
| 474 | Politeness_Disagreement                                              | RuyuanWan/Politeness_Disagreement         |                                               |                | politeness_disagreement                      | Classification      |
| 475 | SBIC_Disagreement                                                    | RuyuanWan/SBIC_Disagreement               |                                               |                | sbic_disagreement                            | Classification      |
| 476 | SChem_Disagreement                                                   | RuyuanWan/SChem_Disagreement              |                                               |                | schem_disagreement                           | Classification      |
| 477 | Dilemmas_Disagreement                                                | RuyuanWan/Dilemmas_Disagreement           |                                               |                | dilemmas_disagreement                        | Classification      |
| 478 | logiqa                                                               | lucasmccabe/logiqa                        |                                               |                | logiqa                                       | MultipleChoice      |
| 479 | wiki_qa                                                              | wiki_qa                                   |                                               |                | wiki_qa                                      | Classification      |
| 480 | cycic_classification                                                 | metaeval/cycic_classification             |                                               |                | cycic_classification                         | Classification      |
| 481 | cycic_multiplechoice                                                 | metaeval/cycic_multiplechoice             |                                               |                | cycic_mc                                     | MultipleChoice      |
| 482 | sts-companion                                                        | metaeval/sts-companion                    |                                               |                | sts_companion                                | Classification      |
| 483 | commonsense_qa_2.0                                                   | metaeval/commonsense_qa_2.0               |                                               |                | commonsense_qa_2                             | Classification      |
| 484 | lingnli                                                              | metaeval/lingnli                          |                                               |                | ling_nli                                     | Classification      |
| 485 | monotonicity-entailment                                              | metaeval/monotonicity-entailment          |                                               |                | monotonicity_entailment                      | Classification      |
| 486 | arct                                                                 | metaeval/arct                             |                                               |                | arct                                         | MultipleChoice      |
| 487 | scinli                                                               | metaeval/scinli                           |                                               |                | scinli                                       | Classification      |
| 488 | naturallogic                                                         | metaeval/naturallogic                     |                                               |                | naturallogic                                 | Classification      |
| 489 | onestop_qa                                                           | onestop_qa                                |                                               |                | onestop_qa                                   | MultipleChoice      |
| 490 | moral_stories/full                                                   | demelin/moral_stories                     | full                                          |                | moral_stories                                | MultipleChoice      |
| 491 | prost                                                                | corypaik/prost                            |                                               |                | prost                                        | MultipleChoice      |
| 492 | dynahate                                                             | aps/dynahate                              |                                               |                | dyna_hate                                    | Classification      |
| 493 | syntactic-augmentation-nli                                           | metaeval/syntactic-augmentation-nli       |                                               |                | syntactic_augmentation_nli                   | Classification      |
| 494 | autotnli                                                             | metaeval/autotnli                         |                                               |                | autotnli                                     | Classification      |
| 495 | CONDAQA                                                              | lasha-nlp/CONDAQA                         |                                               |                | conqada                                      | Classification      |
| 496 | webgpt_comparisons                                                   | openai/webgpt_comparisons                 |                                               |                | webgbpt_comparisons                          | MultipleChoice      |
| 497 | synthetic-instruct-gptj-pairwise                                     | Dahoas/synthetic-instruct-gptj-pairwise   |                                               |                | synthetic_instruct                           | MultipleChoice      |
| 498 | scruples                                                             | metaeval/scruples                         |                                               |                | scruples                                     | Classification      |
| 499 | wouldyourather                                                       | metaeval/wouldyourather                   |                                               |                | wouldyourather                               | MultipleChoice      |
| 500 | attempto-nli                                                         | sileod/attempto-nli                       |                                               |                | attempto_nli                                 | Classification      |
| 501 | defeasible-nli/snli                                                  | metaeval/defeasible-nli                   | snli                                          |                | defeasible_nli                               | Classification      |
| 502 | defeasible-nli/atomic                                                | metaeval/defeasible-nli                   | atomic                                        |                | defeasible_nli                               | Classification      |
| 503 | help-nli                                                             | metaeval/help-nli                         |                                               |                | help_nli                                     | Classification      |
| 504 | nli-veridicality-transitivity                                        | metaeval/nli-veridicality-transitivity    |                                               |                | nli_veridicality_transitivity                | Classification      |
| 505 | natural-language-satisfiability                                      | metaeval/natural-language-satisfiability  |                                               |                | nl_satisfiability                            | Classification      |
| 506 | lonli                                                                | metaeval/lonli                            |                                               |                | lonli                                        | Classification      |
| 507 | dadc-limit-nli                                                       | metaeval/dadc-limit-nli                   |                                               |                | dadc_limit                                   | Classification      |
| 508 | FLUTE                                                                | ColumbiaNLP/FLUTE                         |                                               |                | flute                                        | Classification      |
| 509 | strategy-qa                                                          | metaeval/strategy-qa                      |                                               |                | strategy_qa                                  | Classification      |
| 510 | summarize_from_feedback/comparisons                                  | openai/summarize_from_feedback            | comparisons                                   |                | summarize_from_feedback                      | MultipleChoice      |
| 511 | folio                                                                | metaeval/folio                            |                                               |                | folio                                        | Classification      |
| 512 | tomi-nli                                                             | metaeval/tomi-nli                         |                                               |                | tomi_nli                                     | Classification      |
| 513 | avicenna                                                             | metaeval/avicenna                         |                                               |                | avicenna                                     | Classification      |
| 514 | SHP                                                                  | stanfordnlp/SHP                           |                                               |                | shp                                          | MultipleChoice      |
| 515 | MedQA-USMLE-4-options-hf                                             | GBaker/MedQA-USMLE-4-options-hf           |                                               |                | medqa_usmle                                  | MultipleChoice      |
| 516 | wikimedqa/medwiki                                                    | 14-07-22/wikimedqa                        | medwiki                                       |                | wikimedqa                                    | MultipleChoice      |
| 517 | cicero                                                               | declare-lab/cicero                        |                                               |                | cicero                                       | MultipleChoice      |
| 518 | CREAK                                                                | amydeng2000/CREAK                         |                                               |                | creak                                        | Classification      |
| 519 | mutual                                                               | metaeval/mutual                           |                                               |                | mutual                                       | MultipleChoice      |
| 520 | NeQA                                                                 | inverse-scaling/NeQA                      |                                               |                | neqa                                         | MultipleChoice      |
| 521 | quote-repetition                                                     | inverse-scaling/quote-repetition          |                                               |                | quote_repetition                             | MultipleChoice      |
| 522 | redefine-math                                                        | inverse-scaling/redefine-math             |                                               |                | redefine_math                                | MultipleChoice      |
| 523 | puzzte                                                               | metaeval/puzzte                           |                                               |                | puzzte                                       | Classification      |
| 524 | implicatures                                                         | metaeval/implicatures                     |                                               |                | implicatures                                 | MultipleChoice      |
